<?php

use WHMCS\Database\Capsule;
use WHMCS\Module\Addon\Smsir\Admin;
use WHMCS\Module\Addon\Smsir\Send;
use WHMCS\Module\Addon\Smsir\Setting;
use WHMCS\Module\Addon\Smsir\Template;

//////////////////// invoices ////////////////////
function smsir_invoice($template_name,$vars) {
    $invoice = Capsule::table('tblinvoices')->where('id','=',$vars['invoiceid'])->first();
    $user = Capsule::table('tableusers')->where('id', '=', $invoice->userid)->first();
    $phone = $user->phonenumber;
    $templates = Capsule::table('smsir_templates')->where('name','=',$template_name)->get();
    $smsir = new Setting();
    foreach ($templates as $template) {
        $response = null;
        if ($template->user_fast_send && !empty($template->user_template_number)) {
            $parameters = [
                [
                    'name' => 'invoicenum',
                    'value' => $invoice->invoicenum??$invoice->id
                ],
                [
                    'name' => 'total',
                    'value' => $invoice->total
                ]
            ];
            $response = $smsir->SendFastSms($phone, $template->user_template_number, $parameters);
        } else if (!empty($template->user_message)) {
            $message = str_replace(['%invoicenum%', '%total%'], [$invoice->invoicenum??$invoice->id, $invoice->total], $template->user_message);
            $response = $smsir->SendBulkSms([$phone], $message);
        }
        if($response !== null) {
            (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport($template_name, $phone, $template->name, 'automatic_send', $response);
        }
        $admins = (new Admin())->GetAdminWithPermission(['invoice']);
        foreach ($admins as $admin) {
            $response = null;
            if ($template->admin_fast_send && !empty($template->admin_template_number)) {
                $parameters = [
                    [
                        'name' => 'invoicenum',
                        'value' => $invoice->invoicenum ?? $invoice->id
                    ],
                    [
                        'name' => 'total',
                        'value' => $invoice->total
                    ]
                ];
                $response = $smsir->SendFastSms($phone, $template->user_template_number, $parameters);
            } else if (!empty($template->admin_message)) {
                $message = str_replace(['%invoicenum%', '%total%'], [$invoice->invoicenum ?? $invoice->id, $invoice->total], $template->user_message);
                $response = $smsir->SendBulkSms([$phone], $message);
            }
            if ($response !== null) {
                (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport($template_name, $admin->phone, $template->name, 'automatic_send', $response);
            }
        }
    }
}

// Invoice Created
function smsir_InvoiceCreated($vars) {
    smsir_invoice('invoice_created', $vars);
}
add_hook('InvoiceCreated', 1, 'smsir_invoiceCreated');
// Invoice Paid
function smsir_InvoicePaid($vars) {
    smsir_invoice('invoice_paid', $vars);
}
add_hook('InvoicePaid', 1, 'smsir_invoicePaid');
// Invoice Refunded
function smsir_InvoiceRefund($vars) {
    smsir_invoice('invoice_refunded', $vars);
}
add_hook('InvoiceRefunded', 1, 'smsir_invoiceRefund');
// Invoice Reminder
function smsir_InvoicePaymentReminder($vars) {
    smsir_invoice('invoice_payment_reminder', $vars);
}
add_hook('InvoicePaymentReminder', 1, 'smsir_invoicePaymentReminder');


//////////////////// Tickets ////////////////////
function smsir_ticket($template_name, $vars) {
    $ticket = Capsule::table('tbltickets')->where('id','=',$vars['ticketid'])->first();
    $user = Capsule::table('tableusers')->where('id', '=', $ticket->userid)->first();
    $phone = $user->phonenumber;
    $templates = Capsule::table('smsir_templates')->where('name','=',$template_name)->get();
    $send = new Send();
    foreach ($templates as $template) {
        $response = null;
        if ($template->user_fast_send && !empty($template->user_template_number)) {
            $parameters = [
                [
                    'name' => 'ticketnum',
                    'value' => $ticket->invoicenum??$ticket->id
                ],
            ];
            $message = $template->user_template_number;
            $response = $send->SendFastSms($phone, $template->user_template_number, $parameters);
        } else if (!empty($template->user_message)) {
            $message = str_replace(['%ticketnum%'], [$ticket->ticketnum??$ticket->id], $template->user_message);
            $response = $send->SendBulkSms([$phone], $message);
        }
        if($response !== null) {
            (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport($template_name, $phone, $template->name, 'automatic_send', $response);
        }
        $response = null;
        $admins = (new Admin())->GetAdminWithPermission(['ticket']);
        foreach ($admins as $admin) {
            if ($template->admin_fast_send && !empty($template->admin_template_number)) {
                $parameters = [
                    [
                        'name' => 'ticketnum',
                        'value' => $ticket->invoicenum ?? $ticket->id
                    ],
                ];
                $response = $send->SendFastSms($phone, $template->user_template_number, $parameters);
            } else if (!empty($template->admin_message)) {
                $message = str_replace(['%ticketnum%'], [$ticket->ticketnum ?? $ticket->id], $template->admin_message);
                $response = $send->SendBulkSms([$phone], $message);
            }
            if ($response !== null) {
                (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport($template_name, $admin->phone, $template->name, 'automatic_send', $response);
            }
        }
    }
}
// Ticket Opened
function smsir_TicketOpen($vars) {
    smsir_ticket('ticket_open', $vars);
}
add_hook('TicketOpen', 1, 'smsir_TicketOpen');
// Ticked Closed
function smsir_TicketClose($vars) {
    smsir_ticket('ticket_close', $vars);
}
add_hook('TicketClose', 1, 'smsir_TicketClose');
// Note added to Ticket
function smsir_TicketAddNote($vars) {
    smsir_ticket('ticket_add_note', $vars);
}
add_hook('TicketAddNote', 1, 'smsir_TicketAddNote');
// Admin Replied to Ticket
function smsir_TicketAdminReply($vars) {
    smsir_ticket('ticket_admin_reply', $vars);
}
add_hook('TicketAdminReply', 1, 'smsir_TicketAdminReply');
// Ticket Opened By Admin for User
function smsir_TicketOpenAdmin($vars) {
    smsir_ticket('ticket_open_admin', $vars);
}
add_hook('TicketOpenAdmin', 1, 'smsir_TicketOpenAdmin');
// User Replied to Ticket
function smsir_TicketUserReply($vars) {
    smsir_ticket('ticket_user_reply', $vars);
}
add_hook('TicketUserReply', 1, 'smsir_TicketUserReply');
// Ticket Status Changed
function smsir_TicketStatusChange($vars) {
    smsir_ticket('ticket_status_change', $vars);
}
add_hook('TicketStatusChange', 1, 'smsir_TicketStatusChange');

// Admin Login
function smsir_AdminLogin($vars) {
    logActivity("AdminLogin hook has run. Posted Vars: ". print_r($vars, true));
    $templates = (new Template())->GetTemplatesByEvents('admin_login');
    $admins = (new Admin())->GetAdminWithPermission(['admin_login']);
    $send = new Send();
    logActivity("AdminLogin hook runs templates. Templates: ". print_r($templates, true));
    logActivity("AdminLogin hook runs admins. Admins Vars: ". print_r($admins, true));
    foreach ($templates as $template) {
        logActivity("AdminLogin hook runs foreach 1.");
        foreach ($admins as $admin) {
            logActivity("AdminLogin hook runs foreach 2.");
            $response = null;
            if ($template->admin_fast_send && !empty($template->admin_template_number)) {
                logActivity("AdminLogin hook runs if 1.");
                $parameters = [
                    [
                        'name' => 'username',
                        'value' => $vars['username']
                    ]
                ];
                $response = $send->SendFastSms($admin, $template->admin_template_number, $parameters);
            } else {
                logActivity("AdminLogin hook runs if 2.");
                $message = str_replace(['%username%'], [$vars['username']], $template->admin_message);
                logActivity("AdminLogin hook runs message. Message Vars: ". print_r($message, true));
                $response = $send->SendBulkSms([$admin->phone], $message);
            }
            if($response !== null) {
                logActivity("AdminLogin hook runs response. response Vars: ". print_r($response, true));
                (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport('admin_login', $admin->phone, $template->name, 'automatic_send', $response);
            }
        }
    }
}
add_hook('AdminLogin', 1, 'smsir_AdminLogin');

// Ticket Flagged to specific admin
function smsir_TicketFlagged($vars) {
    //get admin phone number send message to admin
    $ticket = Capsule::table('tbltickets')->where('id','=',$vars['ticketid'])->first();
    $user = Capsule::table('tableusers')->where('id', '=', $ticket->userid)->first();
    $phone = $user->phonenumber;
    $templates = (new Template())->GetTemplatesByEvents('ticket_flagged');
    $send = new Send();
    foreach ($templates as $template) {
        $response = null;
        if ($template->user_fast_send && !empty($template->user_template_number)) {
            $parameters = [
                [
                    'name' => 'ticketnum',
                    'value' => $ticket->invoicenum??$ticket->id
                ],
            ];
            $response = $send->SendFastSms($phone, $template->user_template_number, $parameters);
        } else if (!empty($template->user_message)) {
            $message = str_replace(['%ticketnum%'], [$ticket->ticketnum??$ticket->id], $template->user_message);
            $response = $send->SendBulkSms([$phone], $message);
        }
        if($response !== null) {
            (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport('ticket_flagged', $phone, $template->name, 'automatic_send', $response);
        }
        $response = null;
        $admin = (new Admin())->GetAdmin($vars['adminId']);
        if ($template->admin_fast_send && !empty($template->admin_template_number)) {
            $parameters = [
                [
                    'name' => 'ticketnum',
                    'value' => $ticket->invoicenum??$ticket->id
                ],
            ];
            $response = $send->SendFastSms($admin->phone, $template->user_template_number, $parameters);
        } else if (!empty($template->admin_message)) {
            $message = str_replace(['%ticketnum%'], [$ticket->ticketnum??$ticket->id], $template->admin_message);
            $response = $send->SendBulkSms([$admin->phone], $message);
        }
        if($response !== null) {
            (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport('cancel_and_refund_order', $admin->phone, $template->name, 'automatic_send', $response);
        }
    }
}
add_hook('TicketFlagged', 1, 'smsir_TicketFlagged');

// Order Canceled and refunded
function smsir_cancelAndRefundOrder($vars) {
    $order = Capsule::table('tblorders')->where('id','=',$vars['orderid'])->first();
    $user = Capsule::table('tableusers')->where('id', '=', $order->userid)->first();
    $phone = $user->phonenumber;
    $templates = (new Template())->GetTemplatesByEvents('cancel_and_refund_order');
    $send = new Send();
    foreach ($templates as $template) {
        $response = null;
        if ($template->user_fast_send && !empty($template->user_template_number)) {
            $parameters = [
                [
                    'name' => 'ordernum',
                    'value' => $order->ordernum??$order->id
                ],
            ];
            $response = $send->SendFastSms($phone, $template->user_template_number, $parameters);
        } else if (!empty($template->user_message)) {
            $message = str_replace(['%ordernum%'], [$order->ordernum??$order->id], $template->user_message);
            $response = $send->SendBulkSms([$phone], $message);
        }
        if($response !== null) {
            (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport('cancel_and_refund_order', $phone, $template->name, 'automatic_send', $response);
        }
        $admins = (new Admin())->GetAdminWithPermission(['invoice']);
        foreach ($admins as $admin) {
            $response = null;
            if ($template->admin_fast_send && !empty($template->admin_template_number)) {
                $parameters = [
                    [
                        'name' => 'ordernum',
                        'value' => $order->ordernum ?? $order->id
                    ],
                ];
                $response = $send->SendFastSms($admin->phone, $template->user_template_number, $parameters);
            } else if (!empty($template->admin_message)) {
                $message = str_replace(['%ordernum%'], [$order->ordernum ?? $order->id], $template->admin_message);
                $response = $send->SendBulkSms([$admin->phone], $message);
            }
            if($response !== null) {
                (new \WHMCS\Module\Addon\Smsir\Report())->SaveReport('cancel_and_refund_order', $admin->phone, $template->name, 'automatic_send', $response);
            }
        }
    }

}
add_hook('CancelAndRefundOrder', 1, 'smsir_cancelAndRefundOrder');

function smsir_manualRefund($vars) {
    // smsir_invoice('manual_refund', $vars);
}
add_hook('ManualRefund', 1, 'smsir_manualRefund');
