<?php


use WHMCS\Database\Capsule;
use WHMCS\Module\Addon\Smsir\Report;
use WHMCS\Module\Addon\Smsir\Send;
use WHMCS\Module\Addon\Smsir\Setting;
use WHMCS\Module\Addon\Smsir\Template;
use WHMCS\Module\Addon\Smsir\Admin;

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

function smsir_config() {
    return [
        'name' => 'Sms.ir V2',
        'description' => 'This module is for sending sms with sms.ir apis',
        'author' => 'Pouya Biglari',
        'language' => 'english',
        'version' => '1.0',
    ];
}

function smsir_activate() {
    // Create custom tables and schema required by your module
    try {
        Capsule::schema()
            ->create(
                'smsir_setting',
                function ($table) {
                    /** @var \Illuminate\Database\Schema\Blueprint $table */
                    $table->increments('id');
                    $table->text('name');
                    $table->text('value');
                }
            );
        (new Setting())->SetDefaultSetting();
        Capsule::schema()
            ->create(
                'smsir_admins',
                function ($table) {
                    /** @var \Illuminate\Database\Schema\Blueprint $table */
                    $table->increments('id');
                    $table->integer('admin_id');
                    $table->text('events');
                    $table->text('phone');
                }
            );
        Capsule::schema()
            ->create(
                'smsir_reports',
                function ($table) {
                    /** @var \Illuminate\Database\Schema\Blueprint $table */
                    $table->increments('id');
                    $table->text('status');
                    $table->text('subject');
                    $table->text('send_type');
                    $table->text('mobile');
                    $table->text('message_id');
                    $table->text('message');
                    $table->text('send_at');
                }
            );
        Capsule::schema()
            ->create(
                'smsir_templates',
                function ($table) {
                    /** @var \Illuminate\Database\Schema\Blueprint $table */
                    $table->increments('id');
                    $table->text('name');
                    $table->text('on');
                    $table->integer('user_fast_send')->nullable();
                    $table->text('user_message')->nullable();
                    $table->text('user_message_number')->nullable();
                    $table->text('admin_fast_send')->nullable();
                    $table->text('admin_message')->nullable();
                    $table->text('admin_message_number')->nullable();
                    $table->timestamp('created_at')->nullable();
                }
            );
        return [
            // Supported values here include: success, error or info
            'status' => 'success',
            'description' => 'module successfully activated',
        ];
    } catch (\Exception $e) {
        Capsule::schema()
            ->dropIfExists('smsir_setting');
        Capsule::schema()
            ->dropIfExists('smsir_reports');
        Capsule::schema()
            ->dropIfExists('smsir_templates');
        Capsule::schema()
            ->dropIfExists('smsir_admins');
        return [
            // Supported values here include: success, error or info
            'status' => "error",
            'description' => 'Unable to create tables: ' . $e->getMessage(),
        ];
    }
}

function smsir_deactivate() {
    // Undo any database and schema modifications made by your module here
    try {
        Capsule::schema()
            ->dropIfExists('smsir_setting');
        Capsule::schema()
            ->dropIfExists('smsir_reports');
        Capsule::schema()
            ->dropIfExists('smsir_templates');;
        Capsule::schema()
            ->dropIfExists('smsir_admins');

        return [
            // Supported values here include: success, error or info
            'status' => 'success',
            'description' => 'module successfully deactivated',
        ];
    } catch (\Exception $e) {
        return [
            // Supported values here include: success, error or info
            "status" => "error",
            "description" => "Unable to drop tables: {$e->getMessage()}",
        ];
    }
}

function smsir_upgrade($vars) {
    $currentlyInstalledVersion = $vars['version'];
}

function smsir_output($vars) {
    $action = isset($_REQUEST['action']) ? $_REQUEST['action'] : '';
    $post_action = isset($_REQUEST['postaction']) ? $_REQUEST['postaction'] : '';
    $template = new Template();
    $setting = new Setting();
    $admin = new Admin();
    switch ($post_action) {
        case 'setting':
            $result = $setting->SetSettings($vars);
            break;
        case 'new-template':
            $result = $template->CreateTemplate($vars);
            break;
        case 'update-template':
            $result = $template->UpdateTemplate($_POST['template_id'], $vars);
            break;
        case 'delete-template':
            $result = $template->DeleteTemplate($_GET['template_id'], $vars);
            break;
        case 'new-admin':
            $result = $admin->AddAdmin($vars);
            break;
        case 'update-admin':
            $result = $admin->UpdateAdmin($_POST['admin_id'], $vars);
            break;
        case 'delete-admin':
            $result = $admin->DeleteAdmin($_GET['admin_id'], $vars);
            break;
        case 'send-sms':
            $send = new Send();
            $result = $send->SendSms($vars);
            break;
    }
    $_lang = $vars['_lang'];
    switch ($action) {
        case 'new-template':
            include "templates/TemplateForm.php";
            break;
        case 'edit-template':
            $template_data = $template->GetTemplate($_GET['template_id']);
            include "templates/TemplateEditForm.php";
            break;
        case 'new-admin':
            $admins = (new Admin)->GetWhmcsAdmins();
            include "templates/AdminForm.php";
            break;
        case 'edit-admin':
            $admin_data = $admin->GetAdmin($_GET['admin_id']);
            include "templates/AdminEditForm.php";
            break;
        default:
            $settings = $setting->GetSettings();
            $templates = $template->GetTemplates();
            $admins = $admin->GetAdmins();
            $reports = (new Report())->GetReports();
            include "templates/Home.php";
            break;
    }
}
